resolve_category

Macro resolve_category 

macro_rules! resolve_category {
    ($category:ident) => { ... };
    ($category:literal) => { ... };
}
Resolves a category parameter to a reference to an InternedCategory. If a string literal is provided, it is declared as an external category.