resolve_string

Macro resolve_string 

macro_rules! resolve_string {
    ($string:ident) => { ... };
    ($string:literal) => { ... };
}
Resolves a string parameter to a reference to an InternedString. If a string literal is provided, it is statically interned at compile-time.