macro_rules! begin_scope {
($category:tt, $label:tt $(, $key:tt => $val:expr)* $(,)?) => { ... };
}Expand description
Creates a delegate to capture the given arguments at the beginning of a scope when the given
category is enabled. The returned value should be used to construct a ktrace::Scope to track
the lifetime of the scope and emit the complete trace event. The complete event is associated
with the current thread.
Arguments:
- category: Filter category for the event. Expects a string literal or expression.
- label: Label for the event. Expects a string literal or expression.
- …: List of key => value argument pairs.