macro_rules! resolve_string {
($string:ident) => { ... };
($string:literal) => { ... };
}Expand description
Resolves a string parameter to a reference to an InternedString.
If a string literal is provided, it is statically interned at compile-time.